@@ -17,7 +17,8 @@ def add_orders(orders: OrderList, catalog: Catalog):
     """Adds the provided orders"""
     mapping = Mapping(orders, catalog)
     mapping.initialize_mapping()
-    mapping.confirm()
+    if not confirm("Continue? [Y/n]", default=True):
+        return
 
     for order in orders:
         logger.info(f"Adding order of {order.name} @ {order.flat}:")
