@@ -148,4 +148,4 @@ def add_order(order_data: t.Dict[str, str], price_id, orderobj: Order) -> None:
         sys.exit(1)
     else:
         orderobj.added = True
-        logger.info("Added order!")
+        logger.info(f"Added order (₹{order_data['total']}!")
