@@ -1,4 +1,5 @@
 from typing import Generator
+from rich.table import Table
 
 
 class Product:
@@ -29,6 +30,26 @@ class Catalog:
         except:
             return None
 
+    def print_table(self, console) -> None:
+        tbl = Table(
+            "Product ID",
+            "Product Name",
+            "Description",
+            "Price",
+            "Base quantity",
+            "In Stock?",
+        )
+        for product in self:
+            tbl.add_row(
+                product.product_id,
+                product.name,
+                product.desc,
+                f"₹ {product.price}",
+                product.quantity,
+                str(product.stock),
+            )
+        console.print(tbl)
+
     def __iter__(self) -> Generator[Product, None, None]:
         yield from self.products
 
