@@ -1,18 +1,18 @@
 """Main CLI application"""
 import json
-from time import time
 
 import click
 
 from kiraak.config import API, Auth
 from kiraak.main import main
 from kiraak.get_catalog import download_catalog
+from kiraak import VERSION
 import kiraak.sync
 
 @click.group()
+@click.version_option(VERSION)
 def cli():
     """Kiraak CLI"""
-    pass
 
 @cli.command()
 @click.argument(
