@@ -3,24 +3,22 @@ import time
 
 import click
 from rich.table import Table
+from woocommerce import API
 
 from kiraak import console
 from kiraak.api import get_catalog, login
 from kiraak.catalog import Catalog
 from kiraak.config import Auth
 
-from woocommerce import API
-
 wcapi = API(
     url="https://rgbsocial.redgreenbluemix.com/",
     consumer_key=Auth.WOOCOMMERCE_CONSUMER_KEY,
     consumer_secret=Auth.WOOCOMMERCE_CONSUMER_SECRET,
     wp_api=True,
-    version="wc/v3"
+    version="wc/v3",
 )
 
 
-
 logger = logging.getLogger(__name__)
 
 logger.info(f"Logging in as {Auth.MOBILE}")
@@ -29,6 +27,7 @@ logger.info(
     f"Logged in as {partner_info['partnerName']} @ {partner_info['partnerBrand']}"
 )
 
+
 class WC_Product:
     pass
 
@@ -43,10 +42,10 @@ def compare():
     logger.info("Fetching catalog...")
     catalog = Catalog(get_catalog())
     logger.info(f"Recieved catalog (id {catalog.id})")
-    
+
     prods = []
     i = 1
-    while (new_prods := wcapi.get("products", json={"page": i, "per_page": 20}).json()):
+    while new_prods := wcapi.get("products", json={"page": i, "per_page": 20}).json():
         i += 1
         prods.extend(new_prods)
     print(prods)
