@@ -29,24 +29,7 @@ def main(file: str) -> None:
     logger.info("Fetching catalog...")
     catalog = Catalog(get_catalog())
     logger.info(f"Recieved catalog (id {catalog.id})")
-    tbl = Table(
-        "Product ID",
-        "Product Name",
-        "Description",
-        "Price",
-        "Base quantity",
-        "In Stock?",
-    )
-    for product in catalog:
-        tbl.add_row(
-            product.product_id,
-            product.name,
-            product.desc,
-            f"₹ {product.price}",
-            product.quantity,
-            str(product.stock),
-        )
-    console.print(tbl)
+    catalog.print_table(console)
 
     # Process json file
     logger.info(f"Processing {file}")
